package com.sundata.internalevaluation.configuration.service;

import com.sundata.internalevaluation.configuration.mapper.DataSourcesMapper;
import com.sundata.internalevaluation.configuration.model.DataItemConfigModel;
import com.sundata.internalevaluation.configuration.model.DataSourceModel;
import com.sundata.internalevaluation.configuration.model.InputParamModel;
import com.sundata.internalevaluation.configuration.model.QueryLogicModel;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class DataSourcesService {

    @Autowired
    DataSourcesMapper dataSourcesMapper;

    /**
     * 数据来源配置初始化
     *
     * @param model 查询条件
     * @return 列表
     */
    public List<DataSourceModel> getDataList(DataSourceModel model) {
        return dataSourcesMapper.getDataList(model);
    }


    /**
     * 数据来源配置新增
     *
     * @param model 新增数据
     */
    public void createData(DataSourceModel model) {

        // 先插入数据来源信息
        dataSourcesMapper.createData(model);

        if (null != model.getInputParam() && !model.getInputParam().isEmpty()) {
            dataSourcesMapper.createInputParamData(model.getInputParam());
        }

        if (null != model.getDataItemConfig() && !model.getDataItemConfig().isEmpty()) {
            for (DataItemConfigModel m : model.getDataItemConfig()) {
                m.setDataSourcesNo(model.getDataSourcesNo());
            }
            dataSourcesMapper.createDataItemConfigData(model.getDataItemConfig());
        }

        if (null != model.getQueryLogic() && !model.getQueryLogic().isEmpty()) {
            for (QueryLogicModel m : model.getQueryLogic()) {
                m.setDataSourcesNo(model.getDataSourcesNo());
            }
            dataSourcesMapper.createQueryLogicData(model.getQueryLogic());
        }

    }


    /**
     * 数据来源配置删除
     *
     * @param model 删除条件
     */
    public void deleteRows(DataSourceModel model) {
        dataSourcesMapper.deleteRows(model);
    }


    /**
     * 数据来源配置修改
     *
     * @param model 数据实体
     */
    public void updateExistData(DataSourceModel model) {

        dataSourcesMapper.updateExistData(model);
        dataSourcesMapper.deleteInputParamRows();
        dataSourcesMapper.deleteDataSourceRows(model);
        dataSourcesMapper.deleteQueryLogicRows(model);

        if (null != model.getInputParam() && !model.getInputParam().isEmpty()) {
            dataSourcesMapper.createInputParamData(model.getInputParam());
        }

        if (null != model.getDataItemConfig() && !model.getDataItemConfig().isEmpty()) {
            for (DataItemConfigModel m : model.getDataItemConfig()) {
                m.setDataSourcesNo(model.getDataSourcesNo());
            }
            dataSourcesMapper.createDataItemConfigData(model.getDataItemConfig());
        }

        if (null != model.getQueryLogic() && !model.getQueryLogic().isEmpty()) {
            for (QueryLogicModel m : model.getQueryLogic()) {
                m.setDataSourcesNo(model.getDataSourcesNo());
            }
            dataSourcesMapper.createQueryLogicData(model.getQueryLogic());
        }


    }


    /**
     * 数据来源配置修改
     *
     * @param dataSourcesNo 数据源编号
     * @return 查询结果
     */
    public DataSourceModel selectDetailData(String dataSourcesNo) {
        DataSourceModel model = dataSourcesMapper.selectDetailData(dataSourcesNo);
        List<InputParamModel> inputList = dataSourcesMapper.getInputParamList(dataSourcesNo);
        List<DataItemConfigModel> dataItemList = dataSourcesMapper.getDataItemConfigList(dataSourcesNo);
        List<QueryLogicModel> queryLogicList = dataSourcesMapper.getQueryLogicList(dataSourcesNo);
        model.setInputParam(inputList);
        model.setQueryLogic(queryLogicList);
        model.setDataItemConfig(dataItemList);
        return model;
    }
}
